@@ -91,7 +91,7 @@ get_internals
 copy_png
 image_data_diff
 png_compare
-kungfu
+split_alpha
 /;
 
 our %EXPORT_TAGS = (
@@ -99,7 +99,7 @@ our %EXPORT_TAGS = (
 );
 
 require XSLoader;
-our $VERSION = '0.46_01';
+our $VERSION = '0.46_02';
 
 XSLoader::load('Image::PNG::Libpng', $VERSION);
 
